@@ -1,19 +1,19 @@
-# Copyrights 1995-2016 by [Mark Overmeer <perl@overmeer.net>].
+# Copyrights 1995-2017 by [Mark Overmeer <perl@overmeer.net>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-
-use strict;
 package Mail::Send;
 use vars '$VERSION';
-$VERSION = '2.17';
+$VERSION = '2.19';
 
 
-use Carp;
-require Mail::Mailer;
+use strict;
+
+use Mail::Mailer ();
 
 sub Version { our $VERSION }
 
+#------------------
 
 sub new(@)
 {   my ($class, %attr) = @_;
@@ -27,6 +27,7 @@ sub new(@)
     $self;
 }
 
+#---------------
 
 sub set($@)
 {   my ($self, $hdr, @values) = @_;
@@ -52,6 +53,7 @@ sub cc		{ my $self=shift; $self->set('Cc', @_); }
 sub bcc		{ my $self=shift; $self->set('Bcc', @_); }
 sub subject	{ my $self=shift; $self->set('Subject', join (' ', @_)); }
 
+#---------------
 
 sub open(@)
 {   my $self = shift;
